@@ -71,7 +71,7 @@ MIDDLEWARE = [
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
     'django.middleware.clickjacking.XFrameOptionsMiddleware',
-    'django.middleware.locale.LocaleMiddleware'
+    'garpixcms.middleware.locale.GarpixLocaleMiddleware'
 ]
 
 ROOT_URLCONF = 'app.urls'
@@ -310,3 +310,5 @@ if SENTRY_DSN_STRING != '':
 
 if DEBUG:
     CORS_ALLOW_ALL_ORIGINS = True
+
+GARPIXCMS_CELERY_SETTINGS = 'app.celery.app'
